@@ -3,7 +3,7 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2017 David R. MacIver
+# Most of this work is copyright (C) 2013-2018 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -17,47 +17,37 @@
 
 from __future__ import division, print_function, absolute_import
 
-import warnings
-
 
 class HypothesisException(Exception):
-
     """Generic parent class for exceptions thrown by Hypothesis."""
 
 
 class CleanupFailed(HypothesisException):
-
     """At least one cleanup task failed and no other exception was raised."""
 
 
 class UnsatisfiedAssumption(HypothesisException):
-
     """An internal error raised by assume.
 
     If you're seeing this error something has gone wrong.
-
     """
 
 
 class BadTemplateDraw(HypothesisException):
-
     """An internal error raised when something unfortunate happened during
     template generation and you should restart the draw, preferably with a new
     parameter.
 
     This is not an error condition internally, but if you ever see this
     in your code it's probably a Hypothesis bug
-
     """
 
 
 class NoSuchExample(HypothesisException):
-
     """The condition we have been asked to satisfy appears to be always false.
 
     This does not guarantee that no example exists, only that we were
     unable to find one.
-
     """
 
     def __init__(self, condition_string, extra=''):
@@ -73,19 +63,16 @@ class DefinitelyNoSuchExample(NoSuchExample):  # pragma: no cover
 
     This exception remains for compatibility reasons for now but can
     never actually be thrown.
-
     """
 
 
 class NoExamples(HypothesisException):
-
     """Raised when example() is called on a strategy but we cannot find any
     examples after enough tries that we really should have been able to if this
     was ever going to work."""
 
 
 class Unsatisfiable(HypothesisException):
-
     """We ran out of time or examples before we could find enough examples
     which satisfy the assumptions of this hypothesis.
 
@@ -95,12 +82,10 @@ class Unsatisfiable(HypothesisException):
     strategy or using a better starting point (e.g if you are requiring
     a list has unique values you could instead filter out all duplicate
     values from the list)
-
     """
 
 
 class Flaky(HypothesisException):
-
     """This function appears to fail non-deterministically: We have seen it
     fail when passed this example at least once, but a subsequent invocation
     did not fail.
@@ -114,58 +99,48 @@ class Flaky(HypothesisException):
         3. The function is timing sensitive and can fail or pass depending on
            how long it takes. Try breaking it up into smaller functions which
            don't do that and testing those instead.
-
     """
 
 
 class Timeout(Unsatisfiable):
-
     """We were unable to find enough examples that satisfied the preconditions
     of this hypothesis in the amount of time allotted to us."""
 
 
 class WrongFormat(HypothesisException, ValueError):
-
     """An exception indicating you have attempted to serialize a value that
     does not match the type described by this format."""
 
 
 class BadData(HypothesisException, ValueError):
-
     """The data that we got out of the database does not seem to match the data
     we could have put into the database given this schema."""
 
 
 class InvalidArgument(HypothesisException, TypeError):
-
     """Used to indicate that the arguments to a Hypothesis function were in
     some manner incorrect."""
 
 
 class ResolutionFailed(InvalidArgument):
-
     """Hypothesis had to resolve a type to a strategy, but this failed.
 
     Type inference is best-effort, so this only happens when an
     annotation exists but could not be resolved for a required argument
     to the target of ``builds()``, or where the user passed ``infer``.
-
     """
 
 
 class InvalidState(HypothesisException):
-
     """The system is not in a state where you were allowed to do that."""
 
 
 class InvalidDefinition(HypothesisException, TypeError):
-
     """Used to indicate that a class definition was not well put together and
     has something wrong with it."""
 
 
 class AbnormalExit(HypothesisException):
-
     """Raised when a test running in a child process exits without returning or
     raising an exception."""
 
@@ -179,15 +154,19 @@ class FailedHealthCheck(HypothesisException, Warning):
         self.health_check = check
 
 
-class HypothesisDeprecationWarning(HypothesisException, DeprecationWarning):
-    pass
+class HypothesisWarning(HypothesisException, Warning):
+    """A generic warning issued by Hypothesis."""
 
 
-warnings.simplefilter('once', HypothesisDeprecationWarning)
+class HypothesisDeprecationWarning(HypothesisWarning, FutureWarning):
+    """A deprecation warning issued by Hypothesis.
+
+    Actually inherits from FutureWarning, because DeprecationWarning is
+    hidden by the default warnings filter.
+    """
 
 
 class Frozen(HypothesisException):
-
     """Raised when a mutation method has been called on a ConjectureData object
     after freeze() has been called."""
 
@@ -213,3 +192,7 @@ class StopTest(BaseException):
     def __init__(self, testcounter):
         super(StopTest, self).__init__(repr(testcounter))
         self.testcounter = testcounter
+
+
+class DidNotReproduce(HypothesisException):
+    pass
